@@ -1,5 +1,8 @@
 package HTML::FormFu;
-$HTML::FormFu::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 
@@ -780,7 +783,8 @@ sub param_value {
 
     croak 'name parameter required' if @_ != 2;
 
-    return undef if !$self->valid($name);
+    return undef    ## no critic (ProhibitExplicitReturnUndef);
+        if !$self->valid($name);
 
     # this is guaranteed to always return a single value
 
@@ -1219,7 +1223,7 @@ HTML::FormFu - HTML Form Creation, Rendering and Validation Framework
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
@@ -3175,10 +3179,6 @@ C<vertically-aligned-ie.css>.
 
 =head1 SUPPORT
 
-Website:
-
-L<http://www.formfu.org>
-
 Project Page:
 
 L<http://code.google.com/p/html-formfu/>
