@@ -1,7 +1,10 @@
 package HTML::FormFu::Attribute;
-$HTML::FormFu::Attribute::VERSION = '2.01_02';
+
 use strict;
 use warnings;
+
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Exporter qw( import );
 use Carp qw( croak );
 use Class::MOP::Method;
@@ -516,7 +519,8 @@ sub mk_attr_bool_accessors {
 
             if ( @_ == 1 ) {
                 # Getter
-                return undef if !exists $self->attributes->{$name};
+                return undef    ## no critic (ProhibitExplicitReturnUndef);
+                    if !exists $self->attributes->{$name};
 
                 return $self->attributes->{$name} ? $self->attributes->{$name}
                                                   : undef;
@@ -559,7 +563,7 @@ HTML::FormFu::Attribute - accessor class
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
@@ -571,7 +575,7 @@ version 2.01_02
 
 Carl Franks, C<cfranks@cpan.org>
 
-Based on the original source code of L<HTML::Widget::Accessor>, by 
+Based on the original source code of L<HTML::Widget::Accessor>, by
 Sebastian Riedel, C<sri@oook.de>.
 
 =head1 LICENSE
