@@ -1,5 +1,8 @@
 package HTML::FormFu::Constraint;
-$HTML::FormFu::Constraint::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Processor';
@@ -238,6 +241,7 @@ sub _process_when {
 
     # Callback will be the preferred thing
     if ($when_callback) {
+        ## no critic (ProhibitNoStrict);
         no strict 'refs';
         return $when_callback->( $params, $self );
     }
@@ -351,7 +355,7 @@ HTML::FormFu::Constraint - Constrain User Input
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
@@ -549,11 +553,11 @@ C<$constraint> (the Constraint object)
 
 Return value: $string
 
-Attempt to return the error message that would be used if this constraint 
+Attempt to return the error message that would be used if this constraint
 generated an error.
 
 This will generally be correct for simple constraints with a fixed message or
-which use a placeholder from a known value, such as 
+which use a placeholder from a known value, such as
 L<HTML::FormFu::Constraint::Min/min>.
 This will generally C<not> return the correct message for constraints which
 use L<HTML::FormFu::Role::Constraint::Others/others>, where the field with an
