@@ -1,5 +1,8 @@
 package HTML::FormFu::Constraint::ASCII;
-$HTML::FormFu::Constraint::ASCII::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::Constraint::Regex';
 
@@ -19,7 +22,7 @@ HTML::FormFu::Constraint::ASCII - ASCII Characters Constraint
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 DESCRIPTION
 
