@@ -1,5 +1,8 @@
 package HTML::FormFu::Constraint::AllOrNone;
-$HTML::FormFu::Constraint::AllOrNone::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::Constraint';
 
@@ -72,7 +75,7 @@ HTML::FormFu::Constraint::AllOrNone - Multi-field All or None Constraint
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
@@ -84,8 +87,8 @@ version 2.01_02
 
 Ensure that either all or none of the named fields are present.
 
-By default, if some but not all fields are submitted, errors are attached to 
-those fields which weren't submitted. This behaviour can be changed by setting 
+By default, if some but not all fields are submitted, errors are attached to
+those fields which weren't submitted. This behaviour can be changed by setting
 any of L<HTML::FormFu::Role::Constraint::Others/attach_errors_to_base>,
 L<HTML::FormFu::Role::Constraint::Others/attach_errors_to_others> or
 L<HTML::FormFu::Role::Constraint::Others/attach_errors_to>.
@@ -94,7 +97,7 @@ This constraint doesn't honour the C<not()> value.
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from  
+Is a sub-class of, and inherits methods from
 L<HTML::FormFu::Role::Constraint::Others>, L<HTML::FormFu::Constraint>
 
 L<HTML::FormFu>
