@@ -1,5 +1,8 @@
 package HTML::FormFu::Constraint::AutoSet;
-$HTML::FormFu::Constraint::AutoSet::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::Constraint::Set';
 
@@ -39,7 +42,7 @@ HTML::FormFu::Constraint::AutoSet - Set Constraint for Selects / Radiogroups / C
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 DESCRIPTION
 
