@@ -1,5 +1,8 @@
 package HTML::FormFu::Constraint::Callback;
-$HTML::FormFu::Constraint::Callback::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Constraint';
@@ -11,6 +14,7 @@ sub constrain_value {
 
     my $callback = $self->callback || sub {1};
 
+    ## no critic (ProhibitNoStrict);
     no strict 'refs';
 
     my $ok = $callback->( $value, $params );
@@ -30,7 +34,7 @@ HTML::FormFu::Constraint::Callback - Code Callback Constraint
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
