@@ -1,5 +1,8 @@
 package HTML::FormFu::Constraint::CallbackOnce;
-$HTML::FormFu::Constraint::CallbackOnce::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Constraint';
@@ -16,6 +19,7 @@ sub process {
 
     my $callback = $self->callback || sub {1};
 
+    ## no critic (ProhibitNoStrict);
     no strict 'refs';
 
     my $ok = eval { $callback->( $value, $params ) };
@@ -38,7 +42,7 @@ HTML::FormFu::Constraint::CallbackOnce - Code Callback Constraint
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
@@ -47,7 +51,7 @@ version 2.01_02
         name => 'foo',
         callback => \&sfoo,
     );
-    
+
     sub foo {
         my ( $value, $params ) = @_;
 
@@ -56,12 +60,12 @@ version 2.01_02
 
 =head1 DESCRIPTION
 
-Unlinke the L<HTML::FormFu::Constraint::Callback>, this callback is only 
+Unlinke the L<HTML::FormFu::Constraint::Callback>, this callback is only
 called once, regardless of how many values are submitted.
 
-The first argument passed to the callback is the submitted value for the 
+The first argument passed to the callback is the submitted value for the
 associated field; this may be a single value or an arrayref of value.
-The second argument passed to the callback is a hashref of name/value pairs 
+The second argument passed to the callback is a hashref of name/value pairs
 for all input fields.
 
 This constraint doesn't honour the C<not()> value.
