@@ -1,5 +1,8 @@
 package HTML::FormFu::Constraint::DateTime;
-$HTML::FormFu::Constraint::DateTime::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::Constraint';
 
@@ -51,7 +54,7 @@ HTML::FormFu::Constraint::DateTime - DateTime constraint
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
@@ -61,9 +64,9 @@ version 2.01_02
         name: start_date
         constraints:
           - type: DateTime
-            parser: 
+            parser:
               strptime: '%d-%m-%Y'
-      
+
       - type: Text
         name: end_time
         constraints:
@@ -97,7 +100,7 @@ Ensure input can later be inflated to a DateTime object.
 
 Arguments: \%args
 
-Required. Define the expected input string, so L<DateTime::Format::Builder> 
+Required. Define the expected input string, so L<DateTime::Format::Builder>
 knows how to turn it into a L<DateTime> object.
 
 Accepts arguments to be passed to L<DateTime::Format::Builder/parser>.
