@@ -1,5 +1,8 @@
 package HTML::FormFu::Constraint::Equal;
-$HTML::FormFu::Constraint::Equal::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::Constraint';
 
@@ -121,7 +124,7 @@ HTML::FormFu::Constraint::Equal - Multi-field Equality Constraint
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
@@ -135,12 +138,12 @@ version 2.01_02
 
 =head1 DESCRIPTION
 
-All fields named in L<HTML::FormFu::Role::Constraint::Others/others> must have an equal value to the field this 
+All fields named in L<HTML::FormFu::Role::Constraint::Others/others> must have an equal value to the field this
 constraint is attached to.
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from  
+Is a sub-class of, and inherits methods from
 L<HTML::FormFu::Role::Constraint::Others>, L<HTML::FormFu::Constraint>
 
 L<HTML::FormFu>
