@@ -1,5 +1,8 @@
 package HTML::FormFu::Constraint::File::MaxSize;
-$HTML::FormFu::Constraint::File::MaxSize::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::Constraint::File::Size';
 
@@ -21,13 +24,13 @@ HTML::FormFu::Constraint::File::MaxSize - Maximum File Size Constraint
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 DESCRIPTION
 
 Ensure that an uploaded file meets maximum size constraints.
 
-Overrides L<HTML::FormFu::Constraint/localize_args>, so that the value of 
+Overrides L<HTML::FormFu::Constraint/localize_args>, so that the value of
 L</maximum> is passed as an argument to L<localize|HTML::FormFu/localize>.
 
 This constraint doesn't honour the C<not()> value.
