@@ -1,5 +1,8 @@
 package HTML::FormFu::Constraint::File::MinSize;
-$HTML::FormFu::Constraint::File::MinSize::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::Constraint::File::Size';
 
@@ -21,13 +24,13 @@ HTML::FormFu::Constraint::File::MinSize - Minimum File Size Constraint
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 DESCRIPTION
 
 Ensure that an uploaded file meets minimum size constraints.
 
-Overrides L<HTML::FormFu::Constraint/localize_args>, so that the value of 
+Overrides L<HTML::FormFu::Constraint/localize_args>, so that the value of
 L</minimum> is passed as an argument to L<localize|HTML::FormFu/localize>.
 
 This constraint doesn't honour the C<not()> value.
@@ -44,7 +47,7 @@ L</min> is an alias for L</minimum>.
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from L<HTML::FormFu::File::Size>, 
+Is a sub-class of, and inherits methods from L<HTML::FormFu::File::Size>,
 L<HTML::FormFu::Constraint>
 
 L<HTML::FormFu>
