@@ -1,5 +1,8 @@
 package HTML::FormFu::Constraint::Integer;
-$HTML::FormFu::Constraint::Integer::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::Constraint::Regex';
 
@@ -17,7 +20,7 @@ HTML::FormFu::Constraint::Integer - Unsigned Integer Constraint
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 DESCRIPTION
 
@@ -34,7 +37,7 @@ L<HTML::FormFu>
 
 Carl Franks, C<cfranks@cpan.org>
 
-Based on the original source code of L<HTML::Widget::Constraint::Integer>, by 
+Based on the original source code of L<HTML::Widget::Constraint::Integer>, by
 Sebastian Riedel, C<sri@oook.de>.
 
 =head1 LICENSE
