@@ -1,5 +1,8 @@
 package HTML::FormFu::Constraint::Length;
-$HTML::FormFu::Constraint::Length::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 use MooseX::Aliases;
@@ -52,7 +55,7 @@ HTML::FormFu::Constraint::Length - Min/Max Length String Constraint
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 DESCRIPTION
 
