@@ -1,5 +1,8 @@
 package HTML::FormFu::Constraint::MinMaxFields;
-$HTML::FormFu::Constraint::MinMaxFields::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 use MooseX::Aliases;
@@ -107,7 +110,7 @@ HTML::FormFu::Constraint::MinMaxFields - Min/Max Multi-field Constraint
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
@@ -119,7 +122,7 @@ version 2.01_02
 
 =head1 DESCRIPTION
 
-Ensure that at least a minimum and only a maximum number of fields are 
+Ensure that at least a minimum and only a maximum number of fields are
 present.
 
 This constraint doesn't honour the C<not()> value.
@@ -155,7 +158,7 @@ Default Value: 0
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from  
+Is a sub-class of, and inherits methods from
 L<HTML::FormFu::Role::Constraint::Others>, L<HTML::FormFu::Constraint>
 
 L<HTML::FormFu>
