@@ -1,5 +1,8 @@
 package HTML::FormFu::Constraint::MinRange;
-$HTML::FormFu::Constraint::MinRange::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::Constraint::Range';
 
@@ -21,13 +24,13 @@ HTML::FormFu::Constraint::MinRange - Minimum Value Constraint
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 DESCRIPTION
 
 Checks the input value is equal to or greater than a minimum value.
 
-Overrides L<HTML::FormFu::Constraint/localize_args>, so that the value of 
+Overrides L<HTML::FormFu::Constraint/localize_args>, so that the value of
 L</minimum> is passed as an argument to L<localize|HTML::FormFu/localize>.
 
 This constraint doesn't honour the C<not()> value.
