@@ -1,5 +1,8 @@
 package HTML::FormFu::Constraint::Number;
-$HTML::FormFu::Constraint::Number::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::Constraint';
 
@@ -27,7 +30,7 @@ HTML::FormFu::Constraint::Number - Numerical Constraint
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 DESCRIPTION
 
