@@ -1,5 +1,8 @@
 package HTML::FormFu::Constraint::Printable;
-$HTML::FormFu::Constraint::Printable::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::Constraint::Regex';
 
@@ -19,11 +22,11 @@ HTML::FormFu::Constraint::Printable - Printable Characters Constraint
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 DESCRIPTION
 
-Constraint that checks against the unicode C<print> character class, 
+Constraint that checks against the unicode C<print> character class,
 (Alphanumeric, punct, and space).
 
 =head1 SEE ALSO
