@@ -1,5 +1,8 @@
 package HTML::FormFu::Constraint::Range;
-$HTML::FormFu::Constraint::Range::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 use MooseX::Aliases;
@@ -56,7 +59,7 @@ HTML::FormFu::Constraint::Range - Numerical Range Constraint
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
