@@ -1,5 +1,8 @@
 package HTML::FormFu::Constraint::Regex;
-$HTML::FormFu::Constraint::Regex::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Constraint';
@@ -58,7 +61,7 @@ HTML::FormFu::Constraint::Regex - Regex Constraint
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 DESCRIPTION
 
@@ -78,11 +81,11 @@ Arguments: \@parts
 
 Used to build a L<Regexp::Common> regex.
 
-The following definition is equivalent to 
+The following definition is equivalent to
 C<< $RE{URI}{HTTP}{-scheme => 'https?'} >>
 
     type: Regex
-    common: 
+    common:
       - URI
       - HTTP
       - { '-scheme': 'https?' }
@@ -104,7 +107,7 @@ L<HTML::FormFu>
 
 Carl Franks C<cfranks@cpan.org>
 
-Based on the original source code of L<HTML::Widget::Constraint::Regex>, by 
+Based on the original source code of L<HTML::Widget::Constraint::Regex>, by
 Sebastian Riedel, C<sri@oook.de>.
 
 =head1 LICENSE
