@@ -1,5 +1,8 @@
 package HTML::FormFu::Constraint::Repeatable::Any;
-$HTML::FormFu::Constraint::Repeatable::Any::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 
 extends 'HTML::FormFu::Constraint';
@@ -119,7 +122,7 @@ HTML::FormFu::Constraint::Repeatable::Any - Ensure at least 1 of a repeated fiel
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
