@@ -1,5 +1,8 @@
 package HTML::FormFu::Constraint::Required;
-$HTML::FormFu::Constraint::Required::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::Constraint';
 
@@ -21,7 +24,7 @@ HTML::FormFu::Constraint::Required - Required Field Constraint
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 DESCRIPTION
 
@@ -37,7 +40,7 @@ L<HTML::FormFu>
 
 Carl Franks, C<cfranks@cpan.org>
 
-Based on the original source code of L<HTML::Widget::Constraint::All>, by 
+Based on the original source code of L<HTML::Widget::Constraint::All>, by
 Sebastian Riedel, C<sri@oook.de>.
 
 =head1 LICENSE
