@@ -1,5 +1,8 @@
 package HTML::FormFu::Constraint::Set;
-$HTML::FormFu::Constraint::Set::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Constraint';
@@ -44,7 +47,7 @@ HTML::FormFu::Constraint::Set - Set of Values Constraint
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
