@@ -1,5 +1,8 @@
 package HTML::FormFu::Constraint::SingleValue;
-$HTML::FormFu::Constraint::SingleValue::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::Constraint';
 
@@ -25,7 +28,7 @@ HTML::FormFu::Constraint::SingleValue - Single Value Constraint
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 DESCRIPTION
 
