@@ -1,5 +1,8 @@
 package HTML::FormFu::Constraint::Word;
-$HTML::FormFu::Constraint::Word::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::Constraint::Regex';
 
@@ -19,11 +22,11 @@ HTML::FormFu::Constraint::Word - Single Word Constraint
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 DESCRIPTION
 
-Ensure the input is a single word. Which characters are considered "word 
+Ensure the input is a single word. Which characters are considered "word
 characters" will depend on the current locale.
 
 =head1 SEE ALSO
