@@ -1,5 +1,8 @@
 package HTML::FormFu::Deflator;
-$HTML::FormFu::Deflator::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 
@@ -45,7 +48,7 @@ HTML::FormFu::Deflator - Deflator Base Class
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
