@@ -1,5 +1,8 @@
 package HTML::FormFu::Deflator::Callback;
-$HTML::FormFu::Deflator::Callback::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Deflator';
@@ -11,6 +14,7 @@ sub deflator {
 
     my $callback = $self->callback || sub {shift};
 
+    ## no critic (ProhibitNoStrict);
     no strict 'refs';
 
     return $callback->($value);
@@ -28,7 +32,7 @@ HTML::FormFu::Deflator::Callback - Callback deflator
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
