@@ -1,5 +1,8 @@
 package HTML::FormFu::Deflator::CompoundDateTime;
-$HTML::FormFu::Deflator::CompoundDateTime::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Deflator';
@@ -62,7 +65,7 @@ HTML::FormFu::Deflator::CompoundDateTime - CompoundDateTime deflator
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
@@ -70,17 +73,17 @@ version 2.01_02
     element:
       - type: Multi
         name: date
-        
+
         elements:
           - name: day
           - name: month
           - name: year
-        
+
         deflator:
           - type: CompoundDateTime
 
     # set the default
-    
+
     $form->get_field('date')->default( $datetime );
 
 =head1 DESCRIPTION
@@ -117,20 +120,20 @@ By default, expects the field names to be any of the following:
 
 Arguments: \@order
 
-If your field names don't follow the convention listed above, you must 
-provide an arrayref containing the above names, in the order they correspond 
+If your field names don't follow the convention listed above, you must
+provide an arrayref containing the above names, in the order they correspond
 with your own fields.
 
     ---
     element:
       - type: Multi
         name: date
-        
+
         elements:
           - name: m
           - name: d
           - name: y
-        
+
         deflator:
           - type: CompoundDateTime
             field_order:
