@@ -1,5 +1,8 @@
 package HTML::FormFu::Deflator::PathClassFile;
-$HTML::FormFu::Deflator::PathClassFile::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Deflator';
@@ -44,7 +47,7 @@ HTML::FormFu::Deflator::PathClassFile - Deflator for Path::Class::File objects
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
@@ -68,14 +71,14 @@ There are three types of deflation:
 
 =item relative
 
-Set this to 1 to deflate to a relative path. Anything else than 1 specifies the 
-directory to use as the base of relativity - otherwise the current working 
+Set this to 1 to deflate to a relative path. Anything else than 1 specifies the
+directory to use as the base of relativity - otherwise the current working
 directory will be used.
 
 =item absolute
 
-Set this to 1 to deflate to an absolute path. Anything else than 1 specifies the 
-directory to use as the base of relativity - otherwise the current working 
+Set this to 1 to deflate to an absolute path. Anything else than 1 specifies the
+directory to use as the base of relativity - otherwise the current working
 directory will be used.
 
 =item basename
