@@ -1,5 +1,8 @@
 package HTML::FormFu::Deflator::Strftime;
-$HTML::FormFu::Deflator::Strftime::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Deflator';
@@ -38,7 +41,7 @@ HTML::FormFu::Deflator::Strftime - Strftime deflator
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
