@@ -1,5 +1,8 @@
 package HTML::FormFu::Element::Blank;
-$HTML::FormFu::Element::Blank::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 
 extends 'HTML::FormFu::Element';
@@ -43,13 +46,13 @@ HTML::FormFu::Element::Blank - blank element
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Role::Element::Input>, 
-L<HTML::FormFu::Role::Element::Field>, 
+Is a sub-class of, and inherits methods from
+L<HTML::FormFu::Role::Element::Input>,
+L<HTML::FormFu::Role::Element::Field>,
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
