@@ -1,5 +1,8 @@
 package HTML::FormFu::Element::Button;
-$HTML::FormFu::Element::Button::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 
 extends 'HTML::FormFu::Element';
@@ -27,7 +30,7 @@ HTML::FormFu::Element::Button - Button form field
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
@@ -35,17 +38,17 @@ version 2.01_02
 
 =head1 DESCRIPTION
 
-Button form field, and base-class for L<HTML::FormFu::Element::Image>, 
-L<HTML::FormFu::Element::Reset>, 
+Button form field, and base-class for L<HTML::FormFu::Element::Image>,
+L<HTML::FormFu::Element::Reset>,
 L<HTML::FormFu::Element::Submit>
 
 =head1 METHODS
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Role::Element::Input>, 
-L<HTML::FormFu::Role::Element::Field>, 
+Is a sub-class of, and inherits methods from
+L<HTML::FormFu::Role::Element::Input>,
+L<HTML::FormFu::Role::Element::Field>,
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
