@@ -1,5 +1,8 @@
 package HTML::FormFu::Element::ComboBox;
-$HTML::FormFu::Element::ComboBox::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Element::Multi';
@@ -47,6 +50,7 @@ for my $method ( qw(
 
     my $name = __PACKAGE__ . "::get_${method}s";
 
+    ## no critic (ProhibitNoStrict);
     no strict 'refs';
 
     *{$name} = $sub;
@@ -294,7 +298,7 @@ HTML::FormFu::Element::ComboBox - Select / Text hybrid
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
@@ -314,7 +318,7 @@ Creates a L<multi|HTML::FormFu::Element::Multi> element containing a Select
 field and a Text field.
 
 A ComboBox element named C<foo> would result in a Select menu named
-C<foo_select> and a Text field named C<foo_text>. The names can instead be 
+C<foo_select> and a Text field named C<foo_text>. The names can instead be
 overridden by the C<name> value in L</select> and L</text>.
 
 If a value is submitted for the Text field, this will be used in preference
@@ -373,27 +377,27 @@ Override the auto-generated name of the select menu.
 
 =head1 CAVEATS
 
-Although this element inherits from L<HTML::FormFu::Element::Block>, its 
-behaviour for the methods 
+Although this element inherits from L<HTML::FormFu::Element::Block>, its
+behaviour for the methods
 L<filterE<sol>filters|HTML::FormFu/filters>,
 L<constraintE<sol>constraints|HTML::FormFu/constraints>,
 L<inflatorE<sol>inflators|HTML::FormFu/inflators>,
 L<validatorE<sol>validators|HTML::FormFu/validators> and
 L<transformerE<sol>transformers|HTML::FormFu/transformers> is more like that of
-a L<field element|HTML::FormFu::Role::Element::Field>, meaning all processors are 
+a L<field element|HTML::FormFu::Role::Element::Field>, meaning all processors are
 added directly to the date element, not to its child elements.
 
-This element's L<get_elements|HTML::FormFu/get_elements> and 
-L<get_all_elements|HTML::FormFu/get_all_elements> are inherited from 
-L<HTML::FormFu::Element::Block>, and so have the same behaviour. However, it 
+This element's L<get_elements|HTML::FormFu/get_elements> and
+L<get_all_elements|HTML::FormFu/get_all_elements> are inherited from
+L<HTML::FormFu::Element::Block>, and so have the same behaviour. However, it
 overrides the C<get_fields|HTML::FormFu/get_fields> method, such that it
 returns both itself and its child elements.
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Element::Multi>, 
-L<HTML::FormFu::Element::Block>, 
+Is a sub-class of, and inherits methods from
+L<HTML::FormFu::Element::Multi>,
+L<HTML::FormFu::Element::Block>,
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
