@@ -1,5 +1,8 @@
 package HTML::FormFu::Element::ContentButton;
-$HTML::FormFu::Element::ContentButton::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends "HTML::FormFu::Element";
@@ -71,7 +74,7 @@ HTML::FormFu::Element::ContentButton - Button form field containing markup
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
@@ -94,8 +97,8 @@ content_button form field, rendered using provided markup.
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Role::Element::Field>, 
+Is a sub-class of, and inherits methods from
+L<HTML::FormFu::Role::Element::Field>,
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
