@@ -1,5 +1,8 @@
 package HTML::FormFu::Element::DateTime;
-$HTML::FormFu::Element::DateTime::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Element::Date';
@@ -181,7 +184,7 @@ HTML::FormFu::Element::DateTime - Date / Time combo field
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
@@ -220,10 +223,10 @@ Arguments: $value
 
 Arguments: \@values
 
-A string or arrayref of strings to be inserted into the start of the select 
+A string or arrayref of strings to be inserted into the start of the select
 menu.
 
-Each value is only used as the label for a select item - the value for each 
+Each value is only used as the label for a select item - the value for each
 of these items is always the empty string C<''>.
 
 =head3 prefix_loc
@@ -260,10 +263,10 @@ Arguments: $value
 
 Arguments: \@values
 
-A string or arrayref of strings to be inserted into the start of the select 
+A string or arrayref of strings to be inserted into the start of the select
 menu.
 
-Each value is only used as the label for a select item - the value for each 
+Each value is only used as the label for a select item - the value for each
 of these items is always the empty string C<''>.
 
 =head3 prefix_loc
@@ -300,10 +303,10 @@ Arguments: $value
 
 Arguments: \@values
 
-A string or arrayref of strings to be inserted into the start of the select 
+A string or arrayref of strings to be inserted into the start of the select
 menu.
 
-Each value is only used as the label for a select item - the value for each 
+Each value is only used as the label for a select item - the value for each
 of these items is always the empty string C<''>.
 
 =head3 prefix_loc
@@ -348,9 +351,9 @@ See L<HTML::FormFu::Element::Date/CAVEATS>
 
 Is a sub-class of, and inherits methods from
 L<HTML::FormFu::Element::Date>
-L<HTML::FormFu::Role::Element::Field>, 
-L<HTML::FormFu::Element::Multi>, 
-L<HTML::FormFu::Element::Block>, 
+L<HTML::FormFu::Role::Element::Field>,
+L<HTML::FormFu::Element::Multi>,
+L<HTML::FormFu::Element::Block>,
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
