@@ -1,5 +1,8 @@
 package HTML::FormFu::Element::Email;
-$HTML::FormFu::Element::Email::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 
 extends 'HTML::FormFu::Element';
@@ -28,12 +31,12 @@ HTML::FormFu::Element::Email - HTML5 email form field
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
     my $element = $form->element( Email => 'foo' );
-    
+
     # no need to add a separate Constraint::Email
 
 =head1 DESCRIPTION
@@ -47,9 +50,9 @@ so you don't have to.
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Role::Element::Input>, 
-L<HTML::FormFu::Role::Element::Field>, 
+Is a sub-class of, and inherits methods from
+L<HTML::FormFu::Role::Element::Input>,
+L<HTML::FormFu::Role::Element::Field>,
 L<HTML::FormFu::Element>.
 
 L<HTML::FormFu>
