@@ -1,5 +1,8 @@
 package HTML::FormFu::Element::Fieldset;
-$HTML::FormFu::Element::Fieldset::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::Element::Block';
 
@@ -41,7 +44,7 @@ HTML::FormFu::Element::Fieldset - Fieldset element
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
@@ -61,13 +64,13 @@ If L</legend> is set, it is used as the fieldset's legend
 
 Arguments: $localization_key
 
-To set the legend to a localized string, set L</legend_loc> to a key in 
+To set the legend to a localized string, set L</legend_loc> to a key in
 your L10N file instead of using L</legend>.
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Element::Block>, 
+Is a sub-class of, and inherits methods from
+L<HTML::FormFu::Element::Block>,
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
