@@ -1,5 +1,8 @@
 package HTML::FormFu::Element::File;
-$HTML::FormFu::Element::File::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 
 extends 'HTML::FormFu::Element';
@@ -28,7 +31,7 @@ HTML::FormFu::Element::File - File upload form field
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
@@ -38,14 +41,14 @@ version 2.01_02
       name: photo
 
     my $photo = $form->param('photo');
-    
+
     my $blob = $photo->slurp;
 
 =head1 DESCRIPTION
 
 File upload form field.
 
-See the documentation relevant to the L<query_type|HTML::FormFu/query_type> 
+See the documentation relevant to the L<query_type|HTML::FormFu/query_type>
 you're using:
 
 =over
@@ -62,9 +65,9 @@ you're using:
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Role::Element::Input>, 
-L<HTML::FormFu::Role::Element::Field>, 
+Is a sub-class of, and inherits methods from
+L<HTML::FormFu::Role::Element::Input>,
+L<HTML::FormFu::Role::Element::Field>,
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
