@@ -1,5 +1,8 @@
 package HTML::FormFu::Element::Hr;
-$HTML::FormFu::Element::Hr::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 
 extends 'HTML::FormFu::Element';
@@ -26,7 +29,7 @@ HTML::FormFu::Element::Hr - horizontal-rule element
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 DESCRIPTION
 
@@ -34,8 +37,8 @@ Horizontal-rule element.
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Role::Element::NonBlock>, 
+Is a sub-class of, and inherits methods from
+L<HTML::FormFu::Role::Element::NonBlock>,
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
