@@ -1,5 +1,8 @@
 package HTML::FormFu::Element::Multi;
-$HTML::FormFu::Element::Multi::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::Element::Block';
 
@@ -195,7 +198,7 @@ HTML::FormFu::Element::Multi - Combine multiple fields in a single element
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
@@ -219,8 +222,8 @@ their L<HTML::FormFu/render_method> value.
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Role::Element::Field>, 
+Is a sub-class of, and inherits methods from
+L<HTML::FormFu::Role::Element::Field>,
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
