@@ -1,5 +1,8 @@
 package HTML::FormFu::Element::Number;
-$HTML::FormFu::Element::Number::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 
 extends 'HTML::FormFu::Element::Text';
@@ -38,7 +41,7 @@ HTML::FormFu::Element::Number - Number element with formatting
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
@@ -69,7 +72,7 @@ Set the precision for the number. Defaults to C<2>.
 
 =head2 trailing_zeroes
 
-If this is set to C<1> the number has trailing zeroes. Defaults to C<0>. 
+If this is set to C<1> the number has trailing zeroes. Defaults to C<0>.
 
 =head2 CHANGED BEHAVIOUR AS OF VERSION 0.09011
 
