@@ -1,5 +1,8 @@
 package HTML::FormFu::Element::Radio;
-$HTML::FormFu::Element::Radio::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 
 extends 'HTML::FormFu::Element::Checkbox';
@@ -28,7 +31,7 @@ HTML::FormFu::Element::Radio - Radio form field
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
@@ -41,9 +44,9 @@ Radio form field.
 =head1 SEE ALSO
 
 Is a sub-class of, and inherits methods from
-L<HTML::FormFu::Element::Checkbox>, 
-L<HTML::FormFu::Role::Element::Input>, 
-L<HTML::FormFu::Role::Element::Field>, 
+L<HTML::FormFu::Element::Checkbox>,
+L<HTML::FormFu::Role::Element::Input>,
+L<HTML::FormFu::Role::Element::Field>,
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
