@@ -1,5 +1,8 @@
 package HTML::FormFu::Element::Radiogroup;
-$HTML::FormFu::Element::Radiogroup::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::Element::Checkboxgroup';
 
@@ -26,7 +29,7 @@ HTML::FormFu::Element::Radiogroup - Group of radiobutton form fields
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
@@ -44,8 +47,8 @@ YAML config:
 
 Convenient to use group of radio button fields.
 
-Use the same syntax as you would to create a Select element optgroup to 
-create RadioGroup sub-groups, see L<HTML::FormFu::Role::Element::Group/options> 
+Use the same syntax as you would to create a Select element optgroup to
+create RadioGroup sub-groups, see L<HTML::FormFu::Role::Element::Group/options>
 for details.
 
 =head1 METHODS
@@ -68,8 +71,8 @@ See L<HTML::FormFu::Role::Element::Group/empty_first>.
 
 =head2 auto_id
 
-In addition to the substitutions documented by L<HTML::FormFu/auto_id>, 
-C<%c> will be replaced by an incremented integer, to ensure there are 
+In addition to the substitutions documented by L<HTML::FormFu/auto_id>,
+C<%c> will be replaced by an incremented integer, to ensure there are
 no duplicated ID's.
 
     ---
@@ -88,10 +91,10 @@ See L<HTML::FormFu::Element::Checkboxgroup/reverse_group>.
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Element::Checkboxgroup>, 
-L<HTML::FormFu::Role::Element::Group>, 
-L<HTML::FormFu::Role::Element::Field>, 
+Is a sub-class of, and inherits methods from
+L<HTML::FormFu::Element::Checkboxgroup>,
+L<HTML::FormFu::Role::Element::Group>,
+L<HTML::FormFu::Role::Element::Field>,
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
