@@ -1,5 +1,8 @@
 package HTML::FormFu::Element::Select;
-$HTML::FormFu::Element::Select::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::Element';
 
@@ -34,6 +37,7 @@ sub _prepare_attrs {
     elsif ($submitted
         && $self->retain_default
         && ( !defined $value || $value eq $EMPTY_STR )
+        && defined( $self->value )
         && $self->value eq $option->{value} )
     {
         $option->{attributes}{selected} = 'selected';
@@ -107,7 +111,7 @@ HTML::FormFu::Element::Select - Select form field
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
@@ -125,7 +129,7 @@ YAML config:
 
 Select form field.
 
-Supports optgroups, see L<HTML::FormFu::Role::Element::Group/options> for 
+Supports optgroups, see L<HTML::FormFu::Role::Element::Group/options> for
 details.
 
 =head1 METHODS
@@ -152,9 +156,9 @@ See L<HTML::FormFu::Role::Element::Group/empty_first_label>.
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Role::Element::Group>, 
-L<HTML::FormFu::Role::Element::Field>, 
+Is a sub-class of, and inherits methods from
+L<HTML::FormFu::Role::Element::Group>,
+L<HTML::FormFu::Role::Element::Field>,
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
