@@ -1,5 +1,8 @@
 package HTML::FormFu::Element::Src;
-$HTML::FormFu::Element::Src::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::Element::Block';
 
@@ -23,17 +26,17 @@ HTML::FormFu::Element::Src - custom HTML element
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 DESCRIPTION
 
-Allows you to add markup directly into the form, without surrounding 
+Allows you to add markup directly into the form, without surrounding
 C<< <div> </div> >> tags.
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Element::Block>, 
+Is a sub-class of, and inherits methods from
+L<HTML::FormFu::Element::Block>,
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
