@@ -1,5 +1,8 @@
 package HTML::FormFu::Element::Textarea;
-$HTML::FormFu::Element::Textarea::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 
 extends "HTML::FormFu::Element";
@@ -58,7 +61,7 @@ HTML::FormFu::Element::Textarea - Textarea form field
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
@@ -88,8 +91,8 @@ Return Value: $string
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Role::Element::Field>, 
+Is a sub-class of, and inherits methods from
+L<HTML::FormFu::Role::Element::Field>,
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
