@@ -1,5 +1,8 @@
 package HTML::FormFu::Exception;
-$HTML::FormFu::Exception::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 
 with 'HTML::FormFu::Role::Populate';
