@@ -1,5 +1,8 @@
 package HTML::FormFu::Exception::Input;
-$HTML::FormFu::Exception::Input::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Exception';
