@@ -1,5 +1,8 @@
 package HTML::FormFu::Exception::Validator;
-$HTML::FormFu::Exception::Validator::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::Exception::Input';
 
