@@ -1,5 +1,8 @@
 package HTML::FormFu::Filter::Callback;
-$HTML::FormFu::Filter::Callback::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Filter';
@@ -11,6 +14,7 @@ sub filter {
 
     my $callback = $self->callback || sub {$value};
 
+    ## no critic (ProhibitNoStrict);
     no strict 'refs';
 
     return $callback->( $value, $params );
@@ -28,7 +32,7 @@ HTML::FormFu::Filter::Callback - filter with custom subroutine
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
@@ -47,9 +51,9 @@ version 2.01_02
 
     sub my_filter {
         my ($value) = @_;
-        
+
         # do something to $value
-        
+
         return $value;
     }
 
@@ -69,7 +73,7 @@ Arguments: "subroutine-name"
 
 Carl Franks, C<cfranks@cpan.org>
 
-Based on the original source code of L<HTML::Widget::Filter::Callback>, by 
+Based on the original source code of L<HTML::Widget::Filter::Callback>, by
 Lyo Kato, C<lyo.kato@gmail.com>
 
 =head1 LICENSE
