@@ -1,5 +1,8 @@
 package HTML::FormFu::Filter::CompoundJoin;
-$HTML::FormFu::Filter::CompoundJoin::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Filter';
@@ -41,7 +44,7 @@ HTML::FormFu::Filter::CompoundJoin - CompoundJoin filter
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
