@@ -1,5 +1,8 @@
 package HTML::FormFu::Filter::CompoundSprintf;
-$HTML::FormFu::Filter::CompoundSprintf::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Filter';
@@ -39,7 +42,7 @@ HTML::FormFu::Filter::CompoundSprintf - CompoundSprintf filter
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
@@ -47,18 +50,18 @@ version 2.01_02
     element:
       - type: Multi
         name: date
-        
+
         elements:
           - name: day
           - name: month
           - name: year
-        
+
         filter:
           - type: CompoundSprintf
             sprintf: '%02d-%02d-%04d'
 
     # get the compound-value
-    
+
     my $date = $form->param_value('date');
 
 =head1 DESCRIPTION
@@ -85,12 +88,12 @@ Inherited. See L<HTML::FormFu::Filter::_Compound/field_order> for details.
     element:
       - type: Multi
         name: date
-        
+
         elements:
           - name: month
           - name: day
           - name year
-        
+
         filter:
           - type: CompoundSprintf
             field_order:
