@@ -1,5 +1,8 @@
 package HTML::FormFu::Filter::CopyValue;
-$HTML::FormFu::Filter::CopyValue::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Filter';
@@ -38,7 +41,7 @@ HTML::FormFu::Filter::CopyValue - copy the value from another field
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
