@@ -1,5 +1,8 @@
 package HTML::FormFu::Filter::Encode;
-$HTML::FormFu::Filter::Encode::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Filter';
@@ -90,7 +93,7 @@ HTML::FormFu::Filter::Encode - Encode/Decode Submitted Values
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
