@@ -1,5 +1,8 @@
 package HTML::FormFu::Filter::FormatNumber;
-$HTML::FormFu::Filter::FormatNumber::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::Filter';
 
@@ -44,7 +47,7 @@ HTML::FormFu::Filter::FormatNumber - Convert a formatted number from a known loc
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
@@ -69,7 +72,7 @@ See L<Number::Format/unformat_number> for more details.
 
 If no locale is found, the server's locale will be used.
 
-This method is a special 'inherited accessor', which means it can be set on 
+This method is a special 'inherited accessor', which means it can be set on
 the form, a enclosing block element, the field, or this filter.
 When the value is read, if no value is defined it automatically traverses
 the element's hierarchy of parents, through any block elements and up to the
