@@ -1,5 +1,8 @@
 package HTML::FormFu::Filter::HTMLEscape;
-$HTML::FormFu::Filter::HTMLEscape::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::Filter';
 
@@ -28,7 +31,7 @@ HTML::FormFu::Filter::HTMLEscape - filter escaping HTML
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 DESCRIPTION
 
@@ -38,7 +41,7 @@ HTML escaping filter.
 
 Carl Franks, C<cfranks@cpan.org>
 
-Based on the original source code of L<HTML::Widget::Filter::HTMLEscape>, by 
+Based on the original source code of L<HTML::Widget::Filter::HTMLEscape>, by
 Lyo Kato, C<lyo.kato@gmail.com>
 
 =head1 LICENSE
