@@ -1,5 +1,8 @@
 package HTML::FormFu::Filter::HTMLScrubber;
-$HTML::FormFu::Filter::HTMLScrubber::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Filter';
@@ -53,7 +56,7 @@ HTML::FormFu::Filter::HTMLScrubber - filter removing HTML markup
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 DESCRIPTION
 
@@ -74,7 +77,7 @@ Carl Franks, C<cfranks@cpan.org>
 
 Extended by Nigel Metheringham, C<nigelm@cpan.org>
 
-Based on the original source code of L<HTML::Widget::Filter::HTMLStrip>, by 
+Based on the original source code of L<HTML::Widget::Filter::HTMLStrip>, by
 Lyo Kato, C<lyo.kato@gmail.com>
 
 =head1 LICENSE
