@@ -1,5 +1,8 @@
 package HTML::FormFu::Filter::LowerCase;
-$HTML::FormFu::Filter::LowerCase::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::Filter';
 
@@ -23,7 +26,7 @@ HTML::FormFu::Filter::LowerCase - filter transforming to lower case
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 DESCRIPTION
 
@@ -33,7 +36,7 @@ LowerCase transforming filter.
 
 Carl Franks, C<cfranks@cpan.org>
 
-Based on the original source code of L<HTML::Widget::Filter::LowerCase>, by 
+Based on the original source code of L<HTML::Widget::Filter::LowerCase>, by
 Lyo Kato, C<lyo.kato@gmail.com>
 
 =head1 LICENSE
