@@ -1,5 +1,8 @@
 package HTML::FormFu::Filter::NonNumeric;
-$HTML::FormFu::Filter::NonNumeric::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::Filter::Regex';
 
@@ -17,7 +20,7 @@ HTML::FormFu::Filter::NonNumeric - filter removing all non-numeric characters
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 DESCRIPTION
 
