@@ -1,5 +1,8 @@
 package HTML::FormFu::Filter::Regex;
-$HTML::FormFu::Filter::Regex::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Filter';
@@ -40,7 +43,7 @@ HTML::FormFu::Filter::Regex - regexp-based match/replace filter
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
@@ -58,14 +61,14 @@ Regular expression-based match / replace filter.
 
 =head2 match
 
-A regex object or string to be used in the "left-hand side" of a C<s///g> 
+A regex object or string to be used in the "left-hand side" of a C<s///g>
 regular expression.
 
 Default Value: qr/./
 
 =head2 replace
 
-A string to be used in the "right-hand side" of a C<s///g> regular 
+A string to be used in the "right-hand side" of a C<s///g> regular
 expression. The string will replace every occurrence of L</match>.
 
 Default Value: ''
