@@ -1,5 +1,8 @@
 package HTML::FormFu::Filter::Split;
-$HTML::FormFu::Filter::Split::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Filter';
@@ -36,7 +39,7 @@ HTML::FormFu::Filter::Split - filter splitting a singe value into an arrayref
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
