@@ -1,5 +1,8 @@
 package HTML::FormFu::Filter::TrimEdges;
-$HTML::FormFu::Filter::TrimEdges::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::Filter';
 
@@ -26,7 +29,7 @@ HTML::FormFu::Filter::TrimEdges - filter trimming whitespace
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 DESCRIPTION
 
