@@ -1,5 +1,8 @@
 package HTML::FormFu::Filter::Whitespace;
-$HTML::FormFu::Filter::Whitespace::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::Filter::Regex';
 
@@ -17,7 +20,7 @@ HTML::FormFu::Filter::Whitespace - filter stripping all whitespace
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 DESCRIPTION
 
@@ -27,7 +30,7 @@ Removes all whitespace.
 
 Carl Franks, C<cfranks@cpan.org>
 
-Based on the original source code of L<HTML::Widget::Filter::Whitespace>, by 
+Based on the original source code of L<HTML::Widget::Filter::Whitespace>, by
 Sebastian Riedel, C<sri@oook.de>
 
 =head1 LICENSE
