@@ -1,7 +1,10 @@
 package HTML::FormFu::I18N::de;
-$HTML::FormFu::I18N::de::VERSION = '2.01_02';
+
 use utf8;
 
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::I18N';
 
