@@ -1,5 +1,8 @@
 package HTML::FormFu::I18N::hu;
-$HTML::FormFu::I18N::hu::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use utf8;
 
