@@ -1,5 +1,8 @@
 package HTML::FormFu::Inflator;
-$HTML::FormFu::Inflator::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::Processor';
 
@@ -61,7 +64,7 @@ HTML::FormFu::Inflator - Inflator Base Class
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
