@@ -1,5 +1,8 @@
 package HTML::FormFu::Inflator::DateTime;
-$HTML::FormFu::Inflator::DateTime::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Inflator';
@@ -94,7 +97,7 @@ HTML::FormFu::Inflator::DateTime - DateTime inflator
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
@@ -104,12 +107,12 @@ version 2.01_02
         name: start_date
         inflators:
           - type: DateTime
-            parser: 
+            parser:
               strptime: '%d-%m-%Y'
             strptime:
               pattern: '%d-%b-%Y'
               locale: de
-      
+
       - type: Text
         name: end_time
         inflators:
@@ -147,7 +150,7 @@ For a corresponding deflator, see L<HTML::FormFu::Deflator::Strftime>.
 
 Arguments: \%args
 
-Required. Define the expected input string, so L<DateTime::Format::Builder> 
+Required. Define the expected input string, so L<DateTime::Format::Builder>
 knows how to inflate it into a L<DateTime> object.
 
 Accepts arguments to be passed to L<DateTime::Format::Builder/parser>.
@@ -158,7 +161,7 @@ Arguments: \%args
 
 Arguments: $string
 
-Optional. Define the format that should be used if the L<DateTime> object is 
+Optional. Define the format that should be used if the L<DateTime> object is
 stringified.
 
 =head2 time_zone
@@ -170,9 +173,9 @@ created. This is useful if the string to parse does not contain time zone
 information and you want the DateTime to be in a specific zone instead
 of the floating one (which is likely).
 
-Accepts a hashref of arguments to be passed to 
-L<DateTime::Format::Strptime/new>. Alternatively, accepts a single string 
-argument, suitable for passing to 
+Accepts a hashref of arguments to be passed to
+L<DateTime::Format::Strptime/new>. Alternatively, accepts a single string
+argument, suitable for passing to
 C<< DateTime::Format::Strptime->new( pattern => $string ) >>.
 
 =head1 AUTHOR
