@@ -1,5 +1,8 @@
 package HTML::FormFu::Model;
-$HTML::FormFu::Model::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 
@@ -46,7 +49,7 @@ HTML::FormFu::Model - base class for models
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SEE ALSO
 
