@@ -1,5 +1,8 @@
 package HTML::FormFu::Model::HashRef;
-$HTML::FormFu::Model::HashRef::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 
@@ -273,7 +276,7 @@ sub get_multi {
         foreach my $multi ( @{ $multis || [] } ) {
             my @multis;
             map { push( @multis, $_->name ) } @{ $multi->get_elements };
-            map { s/_\d+//; $multis{$_} = 1 } @multis;
+            map { my $i = $_; $i =~ s/_\d+//; $multis{$i} = 1 } @multis;
         }
         $self->_multi( \%multis );
     }
@@ -314,7 +317,7 @@ HTML::FormFu::Model::HashRef - handle hashrefs
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
@@ -338,17 +341,17 @@ version 2.01_02
         street => 'Somewhere' },
       { id => 3,
         street => 'Somewhere Else' }
-    ]    
+    ]
     } );
-  
+
   $form->default_model('HashRef');
   my $hashref = $form->model->create();
-  
+
   # $hashref is very much the same as the hashref you passed to default_values()
 
 =head1 DESCRIPTION
 
-If you need the content of a formular as hashref or for processing with other modules 
+If you need the content of a formular as hashref or for processing with other modules
 like C<JSON> you can use this model.
 
 =head1 METHODS
@@ -361,7 +364,7 @@ or by simply submitting the form.
 
 If L</deflators> is true all deflators are processed (defaults to C<1>).
 
-If L</options> is true the value of all elements which have options like 
+If L</options> is true the value of all elements which have options like
 L<HTML::FormFu::Element::Select> will be transformed.
 
   ---
