@@ -1,5 +1,8 @@
 package HTML::FormFu::OutputProcessor;
-$HTML::FormFu::OutputProcessor::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 
@@ -29,7 +32,7 @@ HTML::FormFu::OutputProcessor - Post-process HTML output
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 DESCRIPTION
 
