@@ -1,5 +1,8 @@
 package HTML::FormFu::OutputProcessor::Indent;
-$HTML::FormFu::OutputProcessor::Indent::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::OutputProcessor';
@@ -105,7 +108,7 @@ HTML::FormFu::OutputProcessor::Indent - Nicely Indent HTML Output
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
