@@ -1,5 +1,8 @@
 package HTML::FormFu::OutputProcessor::StripWhitespace;
-$HTML::FormFu::OutputProcessor::StripWhitespace::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::OutputProcessor';
@@ -120,7 +123,10 @@ sub process {
 __PACKAGE__->meta->make_immutable;
 
 package HTML::FormFu::OutputProcessor::StripWhitespace::_iter;
-$HTML::FormFu::OutputProcessor::StripWhitespace::_iter::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 
@@ -170,7 +176,7 @@ HTML::FormFu::OutputProcessor::StripWhitespace - Strip shitespace from HTML outp
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
