@@ -1,5 +1,8 @@
 package HTML::FormFu::Plugin;
-$HTML::FormFu::Plugin::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 
@@ -39,7 +42,7 @@ HTML::FormFu::Plugin - base class for plugins
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head2 DESCRIPTION
 
