@@ -1,5 +1,8 @@
 package HTML::FormFu::Plugin::StashValid;
-$HTML::FormFu::Plugin::StashValid::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::Plugin';
 
@@ -28,7 +31,7 @@ HTML::FormFu::Plugin::StashValid - place valid params on form stash
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
@@ -42,14 +45,14 @@ version 2.01_02
     ---
     elements:
       - name: foo
-        plugins: 
+        plugins:
           - StashValid
 
 =head1 DESCRIPTION
 
 Run during the L<HTML::FormFu::Plugin/post_process> hook (called during
 L<HTML::FormFu/process>).
-If the named field(s) have a valid value after processing, that value is 
+If the named field(s) have a valid value after processing, that value is
 placed on the form stash, using the field-name as the stash-key.
 
 =head1 METHODS
