@@ -1,5 +1,8 @@
 package HTML::FormFu::Processor;
-$HTML::FormFu::Processor::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 
@@ -70,7 +73,7 @@ HTML::FormFu::Processor - base class for constraints
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 AUTHOR
 
