@@ -1,5 +1,8 @@
 package HTML::FormFu::QueryType::CGI;
-$HTML::FormFu::QueryType::CGI::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 
 extends 'HTML::FormFu::Upload';
@@ -13,7 +16,7 @@ sub parse_uploads {
     my $query  = $form->query;
     ## CGI wants you to use $query->multi_param($foo).
     ## doing so breaks CGI::Simple. So shoosh it up for now.
-    local $CGI::LIST_CONTEXT_WARN = 0; 
+    local $CGI::LIST_CONTEXT_WARN = 0;
 
     my @params = $query->param($name);
     my @new;
@@ -67,7 +70,7 @@ HTML::FormFu::QueryType::CGI - uploaded file
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 METHODS
 
@@ -102,7 +105,7 @@ Returns the browser-submitted Content-Type of the uploaded file.
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from 
+Is a sub-class of, and inherits methods from
 L<HTML::FormFu::Upload>
 
 L<HTML::FormFu>, L<HTML::FormFu::Element::File>
