@@ -1,5 +1,8 @@
 package HTML::FormFu::QueryType::CGI::Simple;
-$HTML::FormFu::QueryType::CGI::Simple::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 
 extends 'HTML::FormFu::QueryType::CGI';
@@ -56,7 +59,7 @@ HTML::FormFu::QueryType::CGI::Simple - uploaded file
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 METHODS
 
@@ -86,7 +89,7 @@ Inherited, see L<HTML::FormFu::QueryType::CGI/type> for details.
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from 
+Is a sub-class of, and inherits methods from
 L<HTML::FormFu::QueryType::CGI>, L<HTML::FormFu::Upload>
 
 L<HTML::FormFu>, L<HTML::FormFu::Element::File>
