@@ -1,5 +1,8 @@
 package HTML::FormFu::QueryType::Catalyst;
-$HTML::FormFu::QueryType::Catalyst::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 
@@ -76,7 +79,7 @@ HTML::FormFu::QueryType::Catalyst - uploaded file
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 DESCRIPTION
 
@@ -122,7 +125,7 @@ L<Catalyst::Request::Upload|Catalyst::Request::Upload> method.
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from 
+Is a sub-class of, and inherits methods from
 L<HTML::FormFu::Upload>
 
 L<HTML::FormFu>, L<HTML::FormFu::Element::File>
