@@ -1,5 +1,8 @@
 package HTML::FormFu::Role::Constraint::Others;
-$HTML::FormFu::Role::Constraint::Others::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose::Role;
 use MooseX::Attribute::FormFuChained;
 
@@ -214,7 +217,7 @@ HTML::FormFu::Role::Constraint::Others - Base class for constraints needing othe
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 METHODS
 
@@ -236,7 +239,7 @@ to this block are considered siblings.
 
 =head2 attach_errors_to_base
 
-If true, any error will cause the error message to be associated with the 
+If true, any error will cause the error message to be associated with the
 field the constraint is attached to.
 
 Can be use in conjunction with L</attach_errors_to_others>.
@@ -245,7 +248,7 @@ Is ignored if L</attach_errors_to> is set.
 
 =head2 attach_errors_to_others
 
-If true, any error will cause the error message to be associated with every 
+If true, any error will cause the error message to be associated with every
 field named in L</others>.
 
 Can be use in conjunction with L</attach_errors_to_base>.
@@ -256,7 +259,7 @@ Is ignored if L</attach_errors_to> is set.
 
 Arguments: \@field_names
 
-Any error will cause the error message to be associated with every field 
+Any error will cause the error message to be associated with every field
 named in L</attach_errors_to>.
 
 Overrides L</attach_errors_to_base> and L</attach_errors_to_others>.
