@@ -1,5 +1,8 @@
 package HTML::FormFu::Role::CreateChildren;
-$HTML::FormFu::Role::CreateChildren::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose::Role;
 
 use HTML::FormFu::Util qw( _merge_hashes require_class );
