@@ -1,5 +1,8 @@
 package HTML::FormFu::Role::CustomRoles;
-$HTML::FormFu::Role::CustomRoles::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose::Role;
 use Moose::Util qw( ensure_all_roles );
 
