@@ -1,5 +1,8 @@
 package HTML::FormFu::Role::Element::Field;
-$HTML::FormFu::Role::Element::Field::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose::Role;
 use MooseX::Aliases;
 use MooseX::Attribute::FormFuChained;
@@ -1140,7 +1143,7 @@ HTML::FormFu::Role::Element::Field - Role for all form-field elements
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 DESCRIPTION
 
