@@ -1,5 +1,8 @@
 package HTML::FormFu::Role::Element::NonBlock;
-$HTML::FormFu::Role::Element::NonBlock::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose::Role;
 use MooseX::Attribute::FormFuChained;
 
@@ -56,7 +59,7 @@ HTML::FormFu::Role::Element::NonBlock - base class for single-tag elements
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 DESCRIPTION
 
