@@ -1,5 +1,8 @@
 package HTML::FormFu::Role::Element::ProcessOptionsFromModel;
-$HTML::FormFu::Role::Element::ProcessOptionsFromModel::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose::Role;
 
 sub _process_options_from_model {
