@@ -1,5 +1,8 @@
 package HTML::FormFu::Role::Element::SingleValueField;
-$HTML::FormFu::Role::Element::SingleValueField::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose::Role;
 
 use Carp qw( croak );
