@@ -1,5 +1,8 @@
 package HTML::FormFu::Role::FormAndBlockMethods;
-$HTML::FormFu::Role::FormAndBlockMethods::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose::Role;
 
 use HTML::FormFu::Util qw( _merge_hashes );
