@@ -1,5 +1,8 @@
 package HTML::FormFu::Role::FormAndElementMethods;
-$HTML::FormFu::Role::FormAndElementMethods::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose::Role;
 
 use HTML::FormFu::Attribute qw(
