@@ -1,5 +1,8 @@
 package HTML::FormFu::Role::FormBlockAndFieldMethods;
-$HTML::FormFu::Role::FormBlockAndFieldMethods::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose::Role;
 
 use HTML::FormFu::Attribute qw( mk_inherited_accessors );
@@ -41,7 +44,7 @@ HTML::FormFu::Role::FormBlockAndFieldMethods
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 DESCRIPTION
 
