@@ -1,5 +1,8 @@
 package HTML::FormFu::Role::NestedHashUtils;
-$HTML::FormFu::Role::NestedHashUtils::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose::Role;
 
 use HTML::FormFu::Util qw( split_name );
@@ -119,7 +122,7 @@ sub nested_hash_key_exists {
     my ( $root, @names ) = split_name($name);
 
     if ( !@names ) {
-        return exists $param->{$root};
+        return ( defined($root) && exists( $param->{$root} ) );
     }
 
     my $ref = \$param->{$root};
