@@ -1,5 +1,8 @@
 package HTML::FormFu::Role::Populate;
-$HTML::FormFu::Role::Populate::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose::Role;
 
 use Scalar::Util qw( reftype );
