@@ -1,5 +1,8 @@
 package HTML::FormFu::Transformer;
-$HTML::FormFu::Transformer::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::Processor';
 
@@ -62,7 +65,7 @@ HTML::FormFu::Transformer - Transformer Base Class
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
