@@ -1,5 +1,8 @@
 package HTML::FormFu::Upload;
-$HTML::FormFu::Upload::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 
@@ -55,7 +58,7 @@ HTML::FormFu::Upload - uploaded file
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 DESCRIPTION
 
@@ -83,7 +86,7 @@ object is associated with.
 
 =head2 form
 
-Returns the L<HTML::FormFu> object that the upload object's field is attached 
+Returns the L<HTML::FormFu> object that the upload object's field is attached
 to.
 
 =head2 populate
