@@ -1,7 +1,8 @@
 package HTML::FormFu::Util;
-$HTML::FormFu::Util::VERSION = '2.01_02';
+
 use strict;
 use warnings;
+our $VERSION = '2.01_03'; # TRIAL VERSION
 
 use HTML::FormFu::Constants qw( $SPACE );
 use HTML::FormFu::Literal;
@@ -77,7 +78,7 @@ sub debug {
 
     my ( undef, undef, undef, $sub ) = caller(1);
 
-    require 'Data/Dumper.pm';
+    require Data::Dumper;
 
     warn "\n" if $sub ne $LAST_SUB;
 
@@ -397,7 +398,7 @@ sub require_class {
 sub xml_escape {
     my $val = shift;
 
-    return undef if !defined $val;
+    return undef if !defined $val;   ## no critic (ProhibitExplicitReturnUndef);
 
     if ( ref $val eq 'HASH' ) {
         my %val = %$val;
