@@ -1,5 +1,8 @@
 package HTML::FormFu::Validator;
-$HTML::FormFu::Validator::VERSION = '2.01_02';
+
+use strict;
+our $VERSION = '2.01_03'; # TRIAL VERSION
+
 use Moose;
 extends 'HTML::FormFu::Processor';
 
@@ -77,7 +80,7 @@ HTML::FormFu::Validator - Validator Base Class
 
 =head1 VERSION
 
-version 2.01_02
+version 2.01_03
 
 =head1 SYNOPSIS
 
@@ -106,7 +109,10 @@ Then, the form config file would just need:
 And the class would be something like this:
 
     package HTML::FormFu::Validator::MyApp::SomeValidator;
-    use Moose;
+    use strict;
+# VERSION
+
+use Moose;
     extends 'HTML::FormFu::Validator';
 
     sub validate_value {
